@@ -1,20 +1,22 @@
 <?php
-define ( "MODULE_ADMIN_HEADLINE", get_translation ( "BLOCK_IP_ADRESSES" ) );
-define ( "MODULE_ADMIN_REQUIRED_PERMISSION", "block_ips" );
-function block_ips_admin() {
-	if (isset ( $_POST ["submit"] )) {
-		setconfig ( "blocked_ips", db_escape ( $_POST ["blocked_ips"] ) );
-	}
-	
-	$blocked_ips = getconfig ( "blocked_ips" );
-	$blocked_ips = stringHelper::real_htmlspecialchars ( $blocked_ips );
-	?>
+define("MODULE_ADMIN_HEADLINE", get_translation("BLOCK_IP_ADRESSES"));
+define("MODULE_ADMIN_REQUIRED_PERMISSION", "block_ips");
+
+function block_ips_admin()
+{
+    if (isset($_POST["submit"])) {
+        setconfig("blocked_ips", db_escape($_POST["blocked_ips"]));
+    }
+    
+    $blocked_ips = getconfig("blocked_ips");
+    $blocked_ips = StringHelper::realHtmlSpecialchars($blocked_ips);
+    ?>
 
 <form action="<?php echo getModuleAdminSelfPath()?>" method="post">
 <?php
-	
-	csrf_token_html ();
-	?>
+    
+    csrf_token_html();
+    ?>
 <p>
 		Hier können Sie den Zugriff von bestimmten IP-Adressen auf das System
 		blockieren.<br /> Sie können je einen Eintrag pro Zeile eingeben. <br />
@@ -23,9 +25,9 @@ function block_ips_admin() {
 	</p>
 	<p>
 		<textarea rows="10" cols="40" name="blocked_ips"><?php
-	
-	echo $blocked_ips;
-	?></textarea>
+    
+    echo $blocked_ips;
+    ?></textarea>
 	
 	
 	<p>
